==> duiba-galaxy-sdk-0.0.1-20221125.020638-56-sources.jar: cn/com/duiba/galaxy/sdk/DuibaApi.java <==
package cn.com.duiba.galaxy.sdk;

import cn.com.duiba.galaxy.sdk.apiextra.ConsumerApi;
import cn.com.duiba.galaxy.sdk.apiextra.DcustomApi;

public interface DuibaApi extends Api {
//    /**
//     * 风控系统对接
//     *
//     * @return
//     */
//    RiskMDApi getRiskMDApi();

    /**
     * 支持底层获取用户信息
     */

    ConsumerApi getConsumerApi();
//
//    /**
//     * 验证功能接口
//     *
//     * @return
//     */
//    ValidateApi getValidateApi();
//
//
//    /**
//     * 获取签名api
//     *
//     * @return
//     */
//    SignApi getSignApi();
//
//
//    /**
//     * 定制红包接口
//     */
//    RedAccCustomApi getRedAccCustomApi();
//
//    /**
//     * 用户账户服务
//     */
//    ConsumerAccountApi getConsumerAccountApi();
//
//
//    /**
//     * 微信接口
//     */
//    WechatApi getWechatApi();

    /**
     * 获取dcustom
     */
    DcustomApi getDcustomApi();

//    /**
//     * 积分接口
//     *
//     * @return
//     */
//    ConsumerCreditApi getConsumerCreditApi();
//
//    /**
//     * 省市区API
//     *
//     * @return AdministrativeDivisionService
//     */
//    AdministrativeDivisionApi getAdministrativeDivisionService();
//
//    PayApi getPayApi();
//
//    AccountApi getAccountApi();
//
//    SMSValidateApi getSMSValidateApi();
//
//    /**
//     * 获取假用户数据
//     *
//     * @return
//     */
//    FakeUserApi getFakeUserApi();
//
//    /**
//     * 经纬度地址api
//     *
//     * @return
//     */
//    GeoApi getGeoApi();
//
//    /**
//     * Spring环境信息Api
//     *
//     * @return {@link SpringEnvironmentApi}
//     */
//    SpringEnvironmentApi getSpringEnvironmentApi();
}

==> duiba-galaxy-sdk-0.0.3-sources.jar: cn/com/duiba/galaxy/sdk/DuibaApi.java <==
package cn.com.duiba.galaxy.sdk;

import cn.com.duiba.galaxy.sdk.apiextra.ConsumerApi;
import cn.com.duiba.galaxy.sdk.apiextra.DcustomApi;
import cn.com.duiba.galaxy.sdk.pay.PayApi;

public interface DuibaApi extends Api {
//    /**
//     * 风控系统对接
//     *
//     * @return
//     */
//    RiskMDApi getRiskMDApi();

    /**
     * 支持底层获取用户信息
     */

    ConsumerApi getConsumerApi();
//
//    /**
//     * 验证功能接口
//     *
//     * @return
//     */
//    ValidateApi getValidateApi();
//
//
    /**
     * 获取签名api
     *
     * @return
     */
    SignApi getSignApi();
//
//
//    /**
//     * 定制红包接口
//     */
//    RedAccCustomApi getRedAccCustomApi();
//
//    /**
//     * 用户账户服务
//     */
//    ConsumerAccountApi getConsumerAccountApi();
//
//
//    /**
//     * 微信接口
//     */
//    WechatApi getWechatApi();

    /**
     * 获取dcustom
     */
    DcustomApi getDcustomApi();

//    /**
//     * 积分接口
//     *
//     * @return
//     */
//    ConsumerCreditApi getConsumerCreditApi();
//
//    /**
//     * 省市区API
//     *
//     * @return AdministrativeDivisionService
//     */
//    AdministrativeDivisionApi getAdministrativeDivisionService();
//
    PayApi getPayApi();
//
//    AccountApi getAccountApi();
//
//    SMSValidateApi getSMSValidateApi();
//
//    /**
//     * 获取假用户数据
//     *
//     * @return
//     */
//    FakeUserApi getFakeUserApi();
//
//    /**
//     * 经纬度地址api
//     *
//     * @return
//     */
//    GeoApi getGeoApi();
//
//    /**
//     * Spring环境信息Api
//     *
//     * @return {@link SpringEnvironmentApi}
//     */
//    SpringEnvironmentApi getSpringEnvironmentApi();
}
